素媛 (豆瓣)
Description: 素媛电影简介和剧情介绍,素媛影评、图片、预告片、影讯、论坛、在线购票
Keywords: 素媛,소원,素媛影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.34豆瓣电影Top250

# 素媛 소원 (2013)

导演: 李濬益
编剧: 金智慧 / 曹重勋 / 金成旭
主演: 薛景求 / 严志媛 / 李来 / 金海淑 / 金相浩 / 罗美兰 / 杨真诚 / 权泰元
类型: 剧情
官方网站: www.wish-movie.kr
制片国家/地区: 韩国
语言: 韩语
上映日期: 2013-10-02(韩国)
片长: 122分钟
又名: 许愿 / 希望：为爱重生(台) / So-won / Hope
IMDb: tt3153634
豆瓣评分
引用
9.3
650590人评价
5星
69.4%
4星
26.6%
3星
3.7%
2星
0.2%
1星
0.1%
好于 99% 剧情片
想看 看过
评价:
推荐

## 素媛的剧情简介 · · · · · ·

她（李来 饰）是一个美丽平凡的小女孩，和爸爸妈妈生活在位于街角的家中。家里经营着以她的名字素媛命名的杂货店，母亲（严智媛 饰）作为老板娘日夜忙碌不得闲暇，父亲则在工厂干着繁重的工作。在那个飘雨的早上，素媛打着雨伞独自上学。在离学校近在咫尺的地方，她遭遇一个相貌猥琐、酒气冲天的大叔，由此开启了她的悲剧之旅。柔嫩的小花遭到暴风雨无情摧残，受伤的岂止枝枝叶叶，更是那迎着阳光无忧成长的心。无良媒体铺天盖地大肆渲染，作为受害者的素媛一家仿佛成了周身污秽的耻辱之人，被四周诧异好奇的目光所包围。
妈妈悲痛欲绝，几近崩溃。爸爸全力保护女儿，但受伤的小天使却拒绝爸爸的靠近。问凶之路伴随着天使的治愈旅程，美丽的女孩可会再露灿烂笑容？ ©豆瓣

## 素媛的演职员 · · · · · · ( 全部 23 )

- 李濬益 导演
- 薛景求 饰 林东勋
- 严志媛 饰 美熙
- 李来 饰 林素媛
- 金海淑 饰 贞淑
- 金相浩 饰 广植

## 素媛的视频和图片 · · · · · · ( 预告片2 | 添加视频评论 | 图片660 · 添加 )

## 素媛的获奖情况 · · · · · · ( 全部 )

- 第34届韩国电影青龙奖
- 最佳影片

- 第50届百想艺术大赏
- 电影类 最佳影片(提名)
- 李濬益

- 第51届韩国电影大钟奖
- 最佳影片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  猫鼠游戏

  熔炉

  杀人回忆

  恐怖直播

  湄公河行动

  七宗罪

  饮食男女

  小丑

  香水

  沉默的羔羊

我要写短评

## 素媛的短评 · · · · · · ( 全部 140170 条 )

热门 / 最新 / 好友

### 6798 有用 影志 看过 2013-12-27 00:15:44

"最孤独的人最亲切，受过伤的人总是笑的最灿烂，因为他们不愿让身边的人承受一样的痛苦" 从素媛到素望，生活有阳光才有希望，可可梦是全片最治愈点，哭成傻逼。“我总想睡一觉就能回到过去，可早上起来发现，还是没有任何变化，太伤心了...以前奶奶说，哎哟要死要死了，这大概就是人活在世的意义”

### 4230 有用 慈 看过 2013-10-09 20:24:49

“受过伤害的人总是笑得最开心的，因为他们不愿意让身边的人承受一样的痛苦。”

### 2968 有用 Never-land 看过 2013-12-30 23:38:24

太催泪了，素媛和爸爸之间的很多细节都特别感人，素媛住院时，爸爸笨拙的在电脑上搜索“如何和女儿交流”；出院后爸爸悄悄在她床头放上装满糖的小包让她背着来掩盖便袋的声音；还有素媛不再和爸爸亲近，他只能扮成可可梦哄她开心，每次想到笑嘻嘻的可可梦背后是一个无奈的父亲就会觉得特别心酸。

### 5866 有用 呱呱 看过 2013-12-29 19:27:21

爸爸知道女儿介意排便器的塑料声为她准备装满塑料包装纸的糖果小包，女儿知道一直跟着身后的可可梦是爸爸。

### 1011 有用 桃桃林林 看过 2013-12-26 22:04:01

看前面的惨剧其实会略反感，总觉得在消费别人的苦难。好在故事的重心在治愈与亲情，这也是最感人的部分，尤其父亲第二次扮人偶，太催泪了。

> 更多短评 140170条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 素媛的影评 · · · · · · ( 全部 2154 条 )

热门 / 最新 / 好友
skywalker 2014-01-07 16:35:03

## 再温情的心理救助也抵御不了现实的残酷

这篇影评可能有剧透

今天在豆瓣看到了这篇评分9.1的韩国剧情片。不知是豆瓣评分高的缘故，还是对韩国这种类型的片子质量的信任，我在论文未完成、交稿日期快到的时刻，竟然还毫不犹豫地点击观看下去。 韩国犯罪剧情片一直是我的最爱，比如《杀人回忆》、《熔炉》、《恐怖直播》等... (展开)
2412 166 345回应 收起
gohan 2014-02-16 01:34:44

## 我觉得最后是个更残酷的结局，但导演故意没有拍出来

这篇影评可能有剧透

不是我心里黑暗，我感觉最后的结尾暗示着一个残酷的结局，虽然我不喜欢这个猜想，但我觉得除此之外没法解释最后五分钟的剧情。 我觉得她要自杀，而且就是提前回家那天。 最后五分钟的剧情： 镜头先是一个她的座位空着的特写，然后是她走出校园，回头看看学校，转身往家走， ... (展开)
2058 212 425回应 收起
归去何方 2013-11-14 08:12:08

## 观素媛

这篇影评可能有剧透

在伦敦韩国电影节上看到了HOPE这个标题，一开始觉得很俗无非又是励志型社会片，无非又是男女主生活在水深火热之中受到某种刺激冲破枷锁的故事，可是读完简介发现我是大错特错，这是一部励志片，但更是一部反映社会反映人性的理论片。电影是根据真人真事改编，记不清是2009年还... (展开)
1707 289 351回应 收起
kiki204629 2013-12-28 12:23:18

## 『W-I-S-H。』

这篇影评可能有剧透

看罢韩国电影《素媛》，感触颇多。影片让我想到去年看的《熔炉》，压抑敏感的话题，直面现实的勇气，这是让人非常钦佩的。当然，这部电影比《熔炉》要“光明”许多。 这是退隐商业片的李浚益导演回归之作，有薛景求、金海淑这样的实力派加盟，小姑娘的角色在各位演技派面... (展开)
561 25 49回应 收起
TenzinMa 2013-12-29 03:08:34

## 请原谅我的粗俗。

这篇影评可能有剧透

严重剧透说在最前。 看这部电影的心理是这样的： 素媛真可爱，以后我有个这样的姑娘就无憾了~ 素媛太惨了… 我想弄死那个男人！ 我想弄死那个傻逼警察！ 我想弄死素媛他爸。 我想弄死那个傻逼心理咨询师！ 我想弄死那群傻逼记者！！这他妈都是人干的事吗！ 我更想弄死... (展开)
284 92 85回应 收起
橘子 2014-01-13 17:49:30

## 从韩国电影看中韩差距，不一样的角度解读《许愿》

韩国电影总有这么一个特点，明明是拍他们国家的罪案，题材却从中国来拿。从《共谋者》买卖人体器官到《恐怖直播》的弱势群体权益得不到保障到《许愿》小学生被性侵案件，不知道韩国观众有何感想，总之我等中国观众皆感此类电影在抽自己的巴掌。因为这类事件在中国太常见。 我写... (展开)
221 46 79回应 收起
Dak. 2013-10-04 23:00:37

## 所愿的所望

这篇影评可能有剧透

时长122分钟的电影, 展现的是一个女孩子的一生. 一个平凡的家庭, 在工厂上班的父亲, 经营小卖店的母亲, 与一个不谙世事的小女孩, 一家三口平平淡淡的过着日子, 但是一切却在一个下雨天发生改变. 因为'那件事'的发生,给孩子的心灵和身体造成了不可恢复的伤害. ‘那件事’发生... (展开)
147 30 32回应 收起
凝练而歌 2013-12-27 21:43:14

## 作为父亲的愤怒--观《素媛》有感

作为父亲的愤怒--观《素媛》有感 昨晚看了韩国电影《素媛》，一部展示儿童被性侵后如何自我救赎和家人如何面对生活的故事，这样的题材挺敏感的，但是电影拍的很克制，甚至看着觉得温馨和感人（多备纸巾，擦泪用）。但是这种温馨和感人的表面... (展开)
129 6 13回应 收起
小晗要当锦鲤 2018-01-15 21:24:29

## 愿所以孩子都能被世界温柔以待。

这篇影评可能有剧透

素媛看了真的想打人，那种压抑，根本无法用言语来表达。在所谓公平公正的法律面前，好人却始终是不利的一方。电影中女儿对爸爸的微笑的片段真的，很感人，犯罪者却残忍的利用了素媛的善良，为了满足自己恶心的兽欲去伤害了一个年幼善良的孩子，恶心至极。电影中素媛住院，大批... (展开)
82 2 4回应 收起

> 更多影评 2154篇

添加新讨论

## 讨论区 · · · · · ·

法 | 来自李佳恒 |  | 2022-11-24 16:11:32
这部真的是靠实时题材赢的，说实话真的不配9.3分，... | 来自ZMmin | 14 回应 | 2022-11-24 15:22:59
据韩媒报道，韩国电影《素媛》原型罪犯赵斗淳将于1... | 来自乌云朵朵互缠绵 | 18 回应 | 2022-11-08 09:17:39
她妈就不该生素媛弟弟 | 来自WALL·E | 28 回应 | 2022-10-28 11:27:39
看到评论用这个来说中国的简直笑死 | 来自春夜宴于桃花园 |  | 2022-10-28 11:00:48

> 去这部影片的讨论区（全部394条）

## 关于《素媛》的问题 · · · · · · ( 全部65个 )

- 觉得我们都好残酷，我们这算消费她人的不幸与苦难吗？ 34人回答
- 对于影片中出现的风筝，应该怎么理解？ 14人回答

> 全部65个问题

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 木卫清单｜你不应该错过的100部韩国电影 (木卫二)
- 2013新电影（这些，可以期待） (桃桃林林)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- 可乐
  刚刚 看过
- 唧唧复唧唧
  刚刚 看过
- 戒
  2分钟前 看过

1127088人看过 / 331820人想看

订阅素媛的评论:
feed: rss 2.0